# Auto Py to Exe

GitHub Help Post Language:

## Script Location

## Onefile (--onedir / --onefile)

## Console Window (--console / --windowed)

## Icon (--icon)

⚠️ Warning: this file is not a valid .ico file

## Additional Files (--add-data)

Be careful when using additional files with onefile mode; read this and update your code to work with PyInstaller.

If you want to put files in the root directory, put a period (.) in the destination.

## Advanced

## Settings

### auto-py-to-exe Specific Options

Output Directory
Increase Recursion Limit

### Manually Provide Options

Manual Argument Input

### Configuration

## Current Command

## Output

Something wrong with your exe? Read this post on how to fix common issues for possible solutions.
Initializing...